@@ -1,11 +1,15 @@
 #!/usr/bin/perl
 use strict;
 use warnings;
-use Pod::Help qw( -h --help );
 use Config::Any;
 use Data::Dumper ();
 use Regexp::Assemble;
 
+if ( @ARGV == 1 && $ARGV[0] =~ /\A --? h(?:elp)? \z/ix) {
+    help();
+    exit;
+}
+
 if ( @ARGV == 1 ) {
     my $file = $ARGV[0];
     
@@ -45,15 +49,12 @@ if ( @ARGV == 1 ) {
     print "$filename\n";
     print $dumper->Dump;
 }
-elsif ( @ARGV ) {
+else {
     die <<ERROR;
 html_formfu_dumpconf.pl: requires a single filename argument.
 Try "--help" for help.
 ERROR
 }
-else {
-    Pod::Help->help;
-}
 
 sub _config_any_args {
     return (
@@ -61,21 +62,40 @@ sub _config_any_args {
     );
 }
 
+sub help {
+    print <<'HELP';
+html_formfu_dumpconf.pl file.conf
+
+html_formfu_dumpconf.pl file # searches for any supported file extensions
+
+html_formfu_dumpconf.pl --help
+
+=head1 DESCRIPTION
+
+Uses Config::Any and Data::Dumper to display how your config file is parsed.
+HELP
+}
+
 __END__
 
 =head1 NAME
 
-html_formfu_dumpconf.pl
+html_formfu_dumpconf.pl - dump configuration files
+
+=head1 VERSION
+
+version 2.01_1
 
 =head1 SYNOPSIS
 
-    html_formfu_dumpconf.pl file.conf
-    
-    html_formfu_dumpconf.pl file # searches for any supported file extensions
-    
-    html_formfu_dumpconf.pl --help
+    html_formfu_dumpconf.pl F<file.conf>
+
+    html_formfu_dumpconf.pl F<file>
 
 =head1 DESCRIPTION
 
-Uses L<Config::Any> and L<Data::Dumper> to display how your config file is
-parsed.
+Uses Config::Any and Data::Dumper to display how your config file is parsed.
+
+=head1 SEE ALSO
+
+Config::Any, Data::Dumper
