@@ -1,5 +1,5 @@
 package HTML::FormFu;
-$HTML::FormFu::VERSION = '2.00';
+$HTML::FormFu::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -50,7 +50,7 @@ use HTML::FormFu::Util qw(
 use Clone ();
 use List::Util qw( first );
 use List::MoreUtils qw( any none uniq );
-use Scalar::Util qw( blessed refaddr weaken reftype );
+use Scalar::Util qw( blessed weaken reftype );
 use Carp qw( croak );
 
 use overload (
@@ -301,6 +301,10 @@ sub process {
             next if !defined $name;
             next if none { $name eq $_ } @params;
 
+            ## CGI wants you to use $query->multi_param($foo).
+            ## doing so breaks CGI::Simple. So shoosh it up for now.
+            local $CGI::LIST_CONTEXT_WARN = 0;
+
             if ( $field->nested ) {
 
                 # call in list context so we know if there's more than 1 value
@@ -1028,7 +1032,7 @@ sub string {
 
 sub _string_form_start {
     my ( $self, $args_ref ) = @_;
-    
+
     # start_form template
 
     my $render_ref
@@ -1064,13 +1068,13 @@ sub _string_form_start {
             $render_ref->{javascript},
             ;
     }
-    
+
     return $html;
 }
 
 sub _string_form_end {
     my ( $self ) = @_;
-    
+
     # end_form template
 
     return "</form>";
@@ -1213,6 +1217,10 @@ __END__
 
 HTML::FormFu - HTML Form Creation, Rendering and Validation Framework
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
 Note: These examples make use of L<HTML::FormFu::Model::DBIC>. As of
@@ -1619,7 +1627,7 @@ set to C<%d/%m/%Y>:
             Strftime:
                 strftime: '%d/%m/%Y'
 
-An example to make all DateTime elements automatically get an appropriate 
+An example to make all DateTime elements automatically get an appropriate
 Strftime deflator and a DateTime inflator:
 
     default_args:
@@ -1636,14 +1644,14 @@ Strftime deflator and a DateTime inflator:
 =head3 Pseudo types
 
 As a special case, you can also use the C<elements> keys C<Block>, C<Field>
-and C<Input> to match any element which inherits from 
-L<HTML::FormFu::Element::Block> or which C<does> 
+and C<Input> to match any element which inherits from
+L<HTML::FormFu::Element::Block> or which C<does>
 L<HTML::FormFu::Role::Element::Field> or
 L<HTML::FormFu::Role::Element::Input>.
 
 =head3 Alternatives
 
-Each C<elements> key can contain an C<any> list using the C<|> divider: e.g. 
+Each C<elements> key can contain an C<any> list using the C<|> divider: e.g.
 
     # apply the given class to any Element of type Password or Button
     default_args:
@@ -1695,7 +1703,7 @@ stripped-out of the returned C<type()> value. Example:
             'My::Custom::Element':
                 attrs:
                     class: whatever
-    
+
     # do include the leading '+' here
     elements:
         - type: +My::Custom::Element
@@ -1705,7 +1713,7 @@ stripped-out of the returned C<type()> value. Example:
 L</default_args> generates a single hashref to pass to L</populate>, merging
 arguments for each type in turn - meaning L</populate> is only called once
 in total - not once for each type.
-Because scalar values are B<not> merged - this means later values will 
+Because scalar values are B<not> merged - this means later values will
 override earlier values: e.g.
 
     # Normally, calling $field->add_attrs({ class => 'input' })
@@ -2490,15 +2498,15 @@ little extra markup as possible. Many hooks are provided to add
 programatically-generated CSS class names, to allow for a wide-range of
 output styles to be generated by changing only the CSS.
 
-Basic customisation of the markup is possible via the 
+Basic customisation of the markup is possible via the
 L<layout|HTML::FormFu::Role::Element::Field/layout> and
 L<multi_layout|HTML::FormFu::Role::Element::Field/multi_layout> methods.
-This allows you to reorder the position of various parts of each field - 
+This allows you to reorder the position of various parts of each field -
 such as the label, comment, error messages and the input tag - as well
 as inserting any other arbitrary tags you may wish.
 
-If this is not sufficient, you can make completely personalise the markup 
-by telling HTML::FormFu to use an external rendering engine, such as 
+If this is not sufficient, you can make completely personalise the markup
+by telling HTML::FormFu to use an external rendering engine, such as
 L<Template Toolkit|Template> or L<Template::Alloy>.
 See L</render_method> and L</tt_module> for details.
 
@@ -2969,7 +2977,7 @@ replaced by C<attrs>.
 
     # For example, the attributes() method would have all these variant
     # methods available
-    
+
     $form->attributes({ class => 'fancy' });
     $form->attributes_xml({ title => '<b>fancy</b>' });
     $form->attributes_loc({ title => 'fancy' });
@@ -2979,10 +2987,10 @@ replaced by C<attrs>.
     $form->del_attributes({ class => 'fancy' });
     $form->del_attributes_xml({ title => '<b>fancy</b>' });
     $form->del_attributes_loc({ title => 'fancy' });
-    
+
     # Because the method contains the word 'attributes', it also gets the
     # following short-forms
-    
+
     $form->attrs({ class => 'fancy' });
     $form->attrs_xml({ title => '<b>fancy</b>' });
     $form->attrs_loc({ title => 'fancy' });
@@ -3001,7 +3009,7 @@ access individual attribute key/values.
     # Example
     $form->id( 'login' );
     $id = $form->id;
-    
+
     # is equivalent to:
     $form->attributes({ id => 'login' });
     $id = $form->attributes->{id};
@@ -3010,7 +3018,7 @@ All attribute short-cuts also have a C<*_xml> variant.
 
     # Example
     $form->id_xml( $xml );
-    
+
     # is equivalent to:
     $form->attributes_xml({ id => $xml });
 
@@ -3018,7 +3026,7 @@ All attribute short-cuts also have a C<*_loc> variant.
 
     # Example
     $form->title_loc( $key );
-    
+
     # is equivalent to:
     $form->attributes_loc({ title => $key });
 
@@ -3056,11 +3064,11 @@ attribute name, or empty. Any true value will switch the attribute 'on', any
 false value will remove the attribute.
 
     # Example
-    
+
     $field->autofocus(1);
     # equivalent to:
     $field->attributes({ autofocus => 'autofocus' });
-    
+
     $field->autofocus(0);;
     # equivalent to:
     delete $field->attributes->{autofocus};
