@@ -1,5 +1,5 @@
 package HTML::FormFu::Constraint;
-$HTML::FormFu::Constraint::VERSION = '2.00';
+$HTML::FormFu::Constraint::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Processor';
@@ -14,7 +14,6 @@ use Clone ();
 use List::MoreUtils qw( any );
 use Scalar::Util qw( blessed );
 use Carp qw( croak );
-use Clone ();
 use List::MoreUtils qw( any all );
 use List::Util qw( first );
 use Scalar::Util qw( reftype blessed );
@@ -350,6 +349,10 @@ __END__
 
 HTML::FormFu::Constraint - Constrain User Input
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
     ---
