@@ -1,11 +1,12 @@
 package HTML::FormFu::Deploy;
-$HTML::FormFu::Deploy::VERSION = '2.00';
+$HTML::FormFu::Deploy::VERSION = '2.01_1';
 use strict;
+use warnings;
 
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 use Cwd qw( getcwd );
 use Fatal qw( open binmode close mkdir );
-use File::Copy qw( copy move );
+use File::Copy qw( move );
 use File::Find qw( find );
 use File::ShareDir qw( dist_file );
 use File::Spec;
