@@ -1,5 +1,5 @@
 package HTML::FormFu::Element;
-$HTML::FormFu::Element::VERSION = '2.00';
+$HTML::FormFu::Element::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -26,7 +26,7 @@ use HTML::FormFu::ObjectUtil qw(
 );
 use HTML::FormFu::Util qw( require_class xml_escape process_attrs _merge_hashes );
 use Clone ();
-use Scalar::Util qw( refaddr weaken );
+use Scalar::Util qw( weaken );
 use Carp qw( croak );
 
 use overload (
@@ -280,6 +280,10 @@ __END__
 
 HTML::FormFu::Element - Element Base Class
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
     ---
