@@ -1,5 +1,5 @@
 package HTML::FormFu::Element::Checkboxgroup;
-$HTML::FormFu::Element::Checkboxgroup::VERSION = '2.00';
+$HTML::FormFu::Element::Checkboxgroup::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 extends 'HTML::FormFu::Element';
@@ -160,6 +160,10 @@ sub _string_field {
                 process_attrs( $option->{attributes} ),
                 ;
 
+            if ( defined $option->{label} ) {
+                $html .= sprintf "<p>%s</p>\n", $option->{label};
+            }
+
             for my $item ( @{ $option->{group} } ) {
                 $html .= sprintf
                     "<span%s>\n",
@@ -236,6 +240,10 @@ __END__
 
 HTML::FormFu::Element::Checkboxgroup - Group of checkbox form fields
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
 YAML config:
