@@ -1,6 +1,7 @@
 package HTML::FormFu::FakeQuery;
-$HTML::FormFu::FakeQuery::VERSION = '2.00';
+$HTML::FormFu::FakeQuery::VERSION = '2.01_1';
 use strict;
+use warnings;
 use Scalar::Util qw( reftype );
 use Carp qw( croak );
 
@@ -28,6 +29,8 @@ sub new {
     return bless $self, $class;
 }
 
+sub multi_param { goto &param }
+
 sub param {
     my $self = shift;
 
