@@ -1,5 +1,5 @@
 package HTML::FormFu::Filter;
-$HTML::FormFu::Filter::VERSION = '2.00';
+$HTML::FormFu::Filter::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -10,7 +10,6 @@ with 'HTML::FormFu::Role::NestedHashUtils',
 use HTML::FormFu::Attribute qw( mk_inherited_accessors );
 use HTML::FormFu::ObjectUtil qw(
     form name parent nested_name nested_names );
-use Carp qw( croak );
 
 has type => ( is => 'rw', traits => ['FormFuChained'] );
 
@@ -54,6 +53,10 @@ __END__
 
 HTML::FormFu::Filter - Filter Base Class
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
     ---
