@@ -1,11 +1,10 @@
 package HTML::FormFu::Inflator;
-$HTML::FormFu::Inflator::VERSION = '2.00';
+$HTML::FormFu::Inflator::VERSION = '2.01_1';
 use Moose;
 extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Inflator;
 use Scalar::Util qw( blessed );
-use Carp qw( croak );
 
 sub process {
     my ( $self, $values ) = @_;
@@ -20,7 +19,7 @@ sub process {
 
             if ($@) {
                 push @errors, $self->return_error($@);
-                push @return, undef;
+                push @return, $value;
             }
             else {
                 push @return, $return;
@@ -33,6 +32,7 @@ sub process {
 
         if ($@) {
             push @errors, $self->return_error($@);
+            $return = $values;
         }
     }
 
@@ -59,6 +59,10 @@ __END__
 
 HTML::FormFu::Inflator - Inflator Base Class
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SYNOPSIS
 
     my $inflator = $form->inflator( $type, @names );
