@@ -1,6 +1,7 @@
 package HTML::FormFu::Literal;
-$HTML::FormFu::Literal::VERSION = '2.00';
+$HTML::FormFu::Literal::VERSION = '2.01_1';
 use strict;
+use warnings;
 use HTML::FormFu::Constants qw( $EMPTY_STR );
 
 use overload
