@@ -1,6 +1,7 @@
 package HTML::FormFu::Localize;
-$HTML::FormFu::Localize::VERSION = '2.00';
+$HTML::FormFu::Localize::VERSION = '2.01_1';
 use strict;
+use warnings;
 
 use HTML::FormFu::Util qw( require_class );
 use List::MoreUtils qw( any );
