@@ -1,12 +1,11 @@
 package HTML::FormFu::Model;
-$HTML::FormFu::Model::VERSION = '2.00';
+$HTML::FormFu::Model::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::HasParent';
 
 use HTML::FormFu::ObjectUtil qw( form parent );
-use Scalar::Util qw( refaddr reftype );
 use Carp qw( croak );
 
 has type => ( is => 'rw', traits => ['FormFuChained'] );
@@ -45,6 +44,10 @@ __END__
 
 HTML::FormFu::Model - base class for models
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 SEE ALSO
 
 L<HTML::FormFu::Model::DBIC>
