@@ -1,6 +1,7 @@
 package HTML::FormFu::ObjectUtil;
-$HTML::FormFu::ObjectUtil::VERSION = '2.00';
+$HTML::FormFu::ObjectUtil::VERSION = '2.01_1';
 use strict;
+use warnings;
 use Exporter qw( import );
 
 use HTML::FormFu::Util qw(
@@ -10,11 +11,9 @@ use HTML::FormFu::Util qw(
 );
 use Clone ();
 use Config::Any;
-use Clone ();
 use Data::Visitor::Callback;
 use File::Spec;
-use Scalar::Util qw( refaddr reftype weaken blessed );
-use List::MoreUtils qw( none uniq );
+use Scalar::Util qw( refaddr weaken blessed );
 use Carp qw( croak );
 
 our @EXPORT_OK = ( qw(
