@@ -1,13 +1,11 @@
 package HTML::FormFu::OutputProcessor;
-$HTML::FormFu::OutputProcessor::VERSION = '2.00';
+$HTML::FormFu::OutputProcessor::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::HasParent', 'HTML::FormFu::Role::Populate';
 
 use HTML::FormFu::ObjectUtil qw( form parent );
-use Scalar::Util qw( reftype );
-use Carp qw( croak );
 
 has type => ( is => 'rw', traits => ['FormFuChained'] );
 
@@ -29,6 +27,10 @@ __END__
 
 HTML::FormFu::OutputProcessor - Post-process HTML output
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 DESCRIPTION
 
 Post-process a form or element's HTML.
