@@ -1,13 +1,11 @@
 package HTML::FormFu::Plugin;
-$HTML::FormFu::Plugin::VERSION = '2.00';
+$HTML::FormFu::Plugin::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::HasParent', 'HTML::FormFu::Role::Populate';
 
 use HTML::FormFu::ObjectUtil qw( form parent );
-use Scalar::Util qw( refaddr reftype );
-use Carp qw( croak );
 
 has type => ( is => 'rw', traits => ['FormFuChained'] );
 
@@ -39,6 +37,10 @@ __END__
 
 HTML::FormFu::Plugin - base class for plugins
 
+=head1 VERSION
+
+version 2.01_1
+
 =head2 DESCRIPTION
 
 Plugins can be added to a form or any element to modify their behaviour.
