@@ -1,6 +1,8 @@
-package HTML::FormFu::Preload;
-$HTML::FormFu::Preload::VERSION = '2.00';
 use strict;
+use warnings;
+
+package HTML::FormFu::Preload;
+$HTML::FormFu::Preload::VERSION = '2.01_1';
 use HTML::FormFu;
 
 use Module::Pluggable (
