@@ -1,5 +1,5 @@
 package HTML::FormFu::Processor;
-$HTML::FormFu::Processor::VERSION = '2.00';
+$HTML::FormFu::Processor::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
@@ -16,9 +16,6 @@ use HTML::FormFu::ObjectUtil qw(
     name                    nested_name
     nested_names            parent );
 
-use Scalar::Util qw( refaddr reftype );
-use Carp qw( croak );
-
 has type => ( is => 'rw', traits => ['FormFuChained'] );
 
 __PACKAGE__->mk_output_accessors(qw( message ));
@@ -71,6 +68,10 @@ __END__
 
 HTML::FormFu::Processor - base class for constraints
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
