@@ -1,5 +1,5 @@
 package HTML::FormFu::QueryType::CGI;
-$HTML::FormFu::QueryType::CGI::VERSION = '2.00';
+$HTML::FormFu::QueryType::CGI::VERSION = '2.01_1';
 use Moose;
 
 extends 'HTML::FormFu::Upload';
@@ -11,6 +11,10 @@ sub parse_uploads {
     my ( $class, $form, $name ) = @_;
 
     my $query  = $form->query;
+    ## CGI wants you to use $query->multi_param($foo).
+    ## doing so breaks CGI::Simple. So shoosh it up for now.
+    local $CGI::LIST_CONTEXT_WARN = 0; 
+
     my @params = $query->param($name);
     my @new;
 
@@ -61,6 +65,10 @@ __END__
 
 HTML::FormFu::QueryType::CGI - uploaded file
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 METHODS
 
 =head2 headers
