@@ -1,15 +1,12 @@
 package HTML::FormFu::Upload;
-$HTML::FormFu::Upload::VERSION = '2.00';
+$HTML::FormFu::Upload::VERSION = '2.01_1';
 use Moose;
 use MooseX::Attribute::FormFuChained;
 
 with 'HTML::FormFu::Role::Populate';
 
-use Carp qw( croak );
-
 use HTML::FormFu::ObjectUtil qw( form parent );
 use HTML::FormFu::UploadParam;
-use Scalar::Util qw( reftype );
 
 has headers  => ( is => 'rw', traits => ['FormFuChained'] );
 has filename => ( is => 'rw', traits => ['FormFuChained'] );
@@ -56,6 +53,10 @@ __END__
 
 HTML::FormFu::Upload - uploaded file
 
+=head1 VERSION
+
+version 2.01_1
+
 =head1 DESCRIPTION
 
 An instance is created for each uploaded file.
